summaryrefslogtreecommitdiffstats
path: root/kmail/kmfiltermgr.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfiltermgr.cpp')
-rw-r--r--kmail/kmfiltermgr.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kmail/kmfiltermgr.cpp b/kmail/kmfiltermgr.cpp
index 2d1e6c91..b16769c5 100644
--- a/kmail/kmfiltermgr.cpp
+++ b/kmail/kmfiltermgr.cpp
@@ -25,7 +25,7 @@ using KMail::MessageProperty;
#include <klocale.h>
#include <kconfig.h>
-// other Qt headers
+// other TQt headers
#include <tqregexp.h>
#include <tqvaluevector.h>
@@ -125,16 +125,16 @@ int KMFilterMgr::moveMessage(KMMessage *msg) const
void KMFilterMgr::endFiltering(KMMsgBase *msgBase) const
{
- KMFolder *parent = msgBase->parent();
- if ( parent ) {
- if ( parent == MessageProperty::filterFolder( msgBase ) ) {
- parent->take( parent->find( msgBase ) );
+ KMFolder *tqparent = msgBase->tqparent();
+ if ( tqparent ) {
+ if ( tqparent == MessageProperty::filterFolder( msgBase ) ) {
+ tqparent->take( tqparent->tqfind( msgBase ) );
}
else if ( ! MessageProperty::filterFolder( msgBase ) ) {
- int index = parent->find( msgBase );
- KMMessage *msg = parent->getMsg( index );
- parent->take( index );
- parent->addMsgKeepUID( msg );
+ int index = tqparent->tqfind( msgBase );
+ KMMessage *msg = tqparent->getMsg( index );
+ tqparent->take( index );
+ tqparent->addMsgKeepUID( msg );
}
}
MessageProperty::setFiltering( msgBase, false );
@@ -392,7 +392,7 @@ void KMFilterMgr::openDialog( TQWidget *, bool checkForEmptyFilterList )
if( !mEditDialog )
{
//
// We can't use the parent as long as the dialog is modeless
// and there is one shared dialog for all top level windows.
//
mEditDialog = new KMFilterDlg( 0, "filterdialog", bPopFilter,
@@ -437,11 +437,11 @@ const TQString KMFilterMgr::createUniqueName( const TQString & name )
//-----------------------------------------------------------------------------
void KMFilterMgr::appendFilters( const TQValueList<KMFilter*> &filters,
- bool tqreplaceIfNameExists )
+ bool replaceIfNameExists )
{
mDirtyBufferedFolderTarget = true;
beginUpdate();
- if ( tqreplaceIfNameExists ) {
+ if ( replaceIfNameExists ) {
TQValueListConstIterator<KMFilter*> it1 = filters.constBegin();
for ( ; it1 != filters.constEnd() ; ++it1 ) {
TQValueListConstIterator<KMFilter*> it2 = mFilters.constBegin();
@@ -392,7 +392,7 @@ void KMFilterMgr::openDialog( TQWidget *, bool checkForEmptyFilterList )
{
//
- // We can't use the parent as long as the dialog is modeless
+ // We can't use the tqparent as long as the dialog is modeless
// and there is one shared dialog for all top level windows.
//